PersiaML
======

[![tutorials](https://github.com/PersiaML/tutorials/actions/workflows/tutorials.yml/badge.svg)](https://persiaml-tutorials.pages.dev) [![Documentation Status](https://readthedocs.org/projects/persiaml/badge/?version=latest)](https://persiaml.readthedocs.io/en/latest/?badge=latest)
 [![PyPI version](https://badge.fury.io/py/persia.svg)](https://badge.fury.io/py/persia) [![dockerhub](https://github.com/PersiaML/containers/actions/workflows/dockerhub.yml/badge.svg)](https://hub.docker.com/u/persiaml)
